@@ -1,10 +1,7 @@
 use super::Modules;
-use crate::dep_graph::ModuleGraph;
-use crate::ModuleId;
+use crate::{dep_graph::ModuleGraph, ModuleId};
 use std::time::Instant;
-use swc_common::sync::Lrc;
-use swc_common::SourceMap;
-use swc_common::DUMMY_SP;
+use swc_common::{sync::Lrc, SourceMap, DUMMY_SP};
 use swc_ecma_ast::*;
 
 mod chunk;
